slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDMonitorCancel

Clears all monitors for an SVD object.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDMonitorCancel(SVD svd)

Logically Collective on svd

### Input Parameters

| svd | - singular value solver context obtained from SVDCreate()

### Options Database Key

| -svd_monitor_cancel | - Cancels all monitors that have been hardwired into a code by calls to SVDMonitorSet(), but does not cancel those set via the options database.

### See Also

SVDMonitorSet()

### Level

intermediate

### Location

src/svd/interface/svdmon.c
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages